/*
 * DHT11.c
 *
 *  Created on: 22 lut 2017
 *      Author: Mateusz Kuc
 *      Email: kucmateusz92@gmail.com
 */

#include "stm32f0xx_hal.h"
#include "spi.h"
#include "gpio.h"
#include "tim.h"
#include "DHT11.h"

/*
 * PIN z DHT jako wyjście
 * stan wysoki ("1")
 */
void DHT11_OUT_H(void)
{
	GPIO_InitTypeDef GPIO_InitStruct;

	GPIO_InitStruct.Pin = DHT11_Pin;
	GPIO_InitStruct.Mode = GPIO_MODE_OUTPUT_PP;
	GPIO_InitStruct.Pull = GPIO_PULLUP;
	GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_HIGH;
	HAL_GPIO_Init(DHT11_GPIO_Port, &GPIO_InitStruct);
	HAL_GPIO_WritePin(DHT11_GPIO_Port, DHT11_Pin, GPIO_PIN_SET);
}

/*
 * PIN z DHT jako wyjście
 * stan niski ("0")
 */
void DHT11_OUT_L(void)
{
	GPIO_InitTypeDef GPIO_InitStruct;

	GPIO_InitStruct.Pin = DHT11_Pin;
	GPIO_InitStruct.Mode = GPIO_MODE_OUTPUT_OD;
	GPIO_InitStruct.Pull = GPIO_PULLUP;
	GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_HIGH;
	HAL_GPIO_Init(DHT11_GPIO_Port, &GPIO_InitStruct);
	HAL_GPIO_WritePin(DHT11_GPIO_Port, DHT11_Pin, GPIO_PIN_RESET);
}

/*
 * PIN z DHT jako wejście
 * nie zwraca wartosci
 */
void DHT11_IN(void)
{
	GPIO_InitTypeDef GPIO_InitStruct;

	GPIO_InitStruct.Pin = DHT11_Pin;
	GPIO_InitStruct.Mode = GPIO_MODE_INPUT;
	GPIO_InitStruct.Pull = GPIO_PULLUP;
	HAL_GPIO_Init(DHT11_GPIO_Port, &GPIO_InitStruct);
}
void Delay_us(uint16_t us)//funkcja opozniajaca us
{
	TIM17 -> CNT = 0;
	while((TIM17->CNT)<=us);
}

void DHT11(uint8_t dht[])
{
	//dht11[0] i dht11[1] to wilgotnosc, dht11[2] i dht11[3] to temperatura w C, dht11[4] to Check-Sum, dht11[5] to sprawdzenie poprawności transmisji
	//inicjalizacja
	DHT11_OUT_L();//wyjście, niski
	HAL_Delay(18);//opoznienie 18ms
	DHT11_OUT_H();//wyjście, wysoki
	Delay_us(40);
	DHT11_IN();//ustawiam jako wejscie
	if (HAL_GPIO_ReadPin(DHT11_GPIO_Port, DHT11_Pin))//sprawdzam czy DHT odpowiedział, jak dalej jest 1 to znaczy że nie zadziałał
	{
		dht[5] = 0;	//jeżeli mamy w dht[5] zero to znaczy że pojawił sie błąd
	}
	Delay_us(80);
	if (!(HAL_GPIO_ReadPin(DHT11_GPIO_Port, DHT11_Pin)))
	{
		dht[5] = 0;
	}
	Delay_us(80);
	//koniec inicjalizacji

	for (uint8_t i = 0; i < 5; i++)
	{
		uint8_t bajt = 0;
		for (uint8_t j = 0; j < 8; j++)
		{
			while(!(HAL_GPIO_ReadPin(DHT11_GPIO_Port, DHT11_Pin)));//ok 50us
			Delay_us(35);
			if(HAL_GPIO_ReadPin(DHT11_GPIO_Port, DHT11_Pin))
			{
				bajt |= (1 << (7 - j));
			}
			TIM17 -> CNT = 0;
			while(HAL_GPIO_ReadPin(DHT11_GPIO_Port, DHT11_Pin) && ((TIM17->CNT)<=35));//35
		}
		dht[i] = bajt;
	}
}

